package javax.swing.plaf.metal;

import java.awt.Dimension;
import java.awt.Container;
import java.awt.Component;
import java.beans.PropertyChangeEvent;
import javax.swing.border.EmptyBorder;
import javax.swing.JButton;
import java.awt.FontMetrics;
import java.awt.Font;
import java.awt.Rectangle;
import sun.swing.SwingUtilities2;
import javax.swing.plaf.ColorUIResource;
import java.awt.Graphics;
import java.awt.LayoutManager;
import java.beans.PropertyChangeListener;
import javax.swing.JMenu;
import javax.swing.UIManager;
import javax.swing.JInternalFrame;
import java.awt.Color;
import javax.swing.border.Border;
import javax.swing.Icon;
import javax.swing.plaf.basic.BasicInternalFrameTitlePane;

public class MetalInternalFrameTitlePane extends BasicInternalFrameTitlePane
{
    protected boolean isPalette;
    protected Icon paletteCloseIcon;
    protected int paletteTitleHeight;
    private static final Border handyEmptyBorder;
    private String selectedBackgroundKey;
    private String selectedForegroundKey;
    private String selectedShadowKey;
    private boolean wasClosable;
    int buttonsWidth;
    MetalBumps activeBumps;
    MetalBumps inactiveBumps;
    MetalBumps paletteBumps;
    private Color activeBumpsHighlight;
    private Color activeBumpsShadow;
    
    public MetalInternalFrameTitlePane(JInternalFrame f) {
        super(f);
        this.isPalette = false;
        this.buttonsWidth = 0;
        this.activeBumps = new MetalBumps(0, 0, MetalLookAndFeel.getPrimaryControlHighlight(), MetalLookAndFeel.getPrimaryControlDarkShadow(), (UIManager.get("InternalFrame.activeTitleGradient") != null) ? null : MetalLookAndFeel.getPrimaryControl());
        this.inactiveBumps = new MetalBumps(0, 0, MetalLookAndFeel.getControlHighlight(), MetalLookAndFeel.getControlDarkShadow(), (UIManager.get("InternalFrame.inactiveTitleGradient") != null) ? null : MetalLookAndFeel.getControl());
        this.activeBumpsHighlight = MetalLookAndFeel.getPrimaryControlHighlight();
        this.activeBumpsShadow = MetalLookAndFeel.getPrimaryControlDarkShadow();
    }
    
    @Override
    public void addNotify() {
        super.addNotify();
        this.updateOptionPaneState();
    }
    
    @Override
    protected void installDefaults() {
        super.installDefaults();
        this.setFont(UIManager.getFont("InternalFrame.titleFont"));
        this.paletteTitleHeight = UIManager.getInt("InternalFrame.paletteTitleHeight");
        this.paletteCloseIcon = UIManager.getIcon("InternalFrame.paletteCloseIcon");
        this.wasClosable = this.frame.isClosable();
        String s = null;
        this.selectedBackgroundKey = s;
        this.selectedForegroundKey = s;
        if (MetalLookAndFeel.usingOcean()) {
            this.setOpaque(true);
        }
    }
    
    @Override
    protected void uninstallDefaults() {
        super.uninstallDefaults();
        if (this.wasClosable != this.frame.isClosable()) {
            this.frame.setClosable(this.wasClosable);
        }
    }
    
    @Override
    protected void createButtons() {
        super.createButtons();
        Boolean value = this.frame.isSelected() ? Boolean.TRUE : Boolean.FALSE;
        this.iconButton.putClientProperty("paintActive", value);
        this.iconButton.setBorder(MetalInternalFrameTitlePane.handyEmptyBorder);
        this.maxButton.putClientProperty("paintActive", value);
        this.maxButton.setBorder(MetalInternalFrameTitlePane.handyEmptyBorder);
        this.closeButton.putClientProperty("paintActive", value);
        this.closeButton.setBorder(MetalInternalFrameTitlePane.handyEmptyBorder);
        this.closeButton.setBackground(MetalLookAndFeel.getPrimaryControlShadow());
        if (MetalLookAndFeel.usingOcean()) {
            this.iconButton.setContentAreaFilled(false);
            this.maxButton.setContentAreaFilled(false);
            this.closeButton.setContentAreaFilled(false);
        }
    }
    
    @Override
    protected void assembleSystemMenu() {
    }
    
    @Override
    protected void addSystemMenuItems(JMenu menu) {
    }
    
    @Override
    protected void showSystemMenu() {
    }
    
    @Override
    protected void addSubComponents() {
        this.add(this.iconButton);
        this.add(this.maxButton);
        this.add(this.closeButton);
    }
    
    @Override
    protected PropertyChangeListener createPropertyChangeListener() {
        return new MetalInternalFrameTitlePane.MetalPropertyChangeHandler();
    }
    
    @Override
    protected LayoutManager createLayout() {
        return new MetalInternalFrameTitlePane.MetalTitlePaneLayout();
    }
    
    public void paintPalette(Graphics graphics) {
        int leftToRight = MetalUtils.isLeftToRight(this.frame);
        int width = this.getWidth();
        int height = this.getHeight();
        if (this.paletteBumps == null) {
            this.paletteBumps = new MetalBumps(0, 0, MetalLookAndFeel.getPrimaryControlHighlight(), MetalLookAndFeel.getPrimaryControlInfo(), MetalLookAndFeel.getPrimaryControlShadow());
        }
        ColorUIResource primaryControlShadow = MetalLookAndFeel.getPrimaryControlShadow();
        ColorUIResource primaryControlDarkShadow = MetalLookAndFeel.getPrimaryControlDarkShadow();
        graphics.setColor(primaryControlShadow);
        graphics.fillRect(0, 0, width, height);
        graphics.setColor(primaryControlDarkShadow);
        graphics.drawLine(0, height - 1, width, height - 1);
        int n = leftToRight ? 4 : (this.buttonsWidth + 4);
        this.paletteBumps.setBumpArea(width - this.buttonsWidth - 8, this.getHeight() - 4);
        this.paletteBumps.paintIcon(this, graphics, n, 2);
    }
    
    @Override
    public void paintComponent(Graphics graphics) {
        if (this.isPalette) {
            this.paintPalette(graphics);
            return;
        }
        int leftToRight = MetalUtils.isLeftToRight(this.frame);
        int selected = this.frame.isSelected();
        int width = this.getWidth();
        int height = this.getHeight();
        ColorUIResource color = null;
        ColorUIResource color2 = null;
        ColorUIResource color3 = null;
        MetalBumps metalBumps;
        String s;
        if (!(selected == 0)) {
            if (!MetalLookAndFeel.usingOcean()) {
                this.closeButton.setContentAreaFilled(true);
                this.maxButton.setContentAreaFilled(true);
                this.iconButton.setContentAreaFilled(true);
            }
            if (this.selectedBackgroundKey != null) {
                color = UIManager.getColor(this.selectedBackgroundKey);
            }
            if (color == null) {
                color = MetalLookAndFeel.getWindowTitleBackground();
            }
            if (this.selectedForegroundKey != null) {
                color2 = UIManager.getColor(this.selectedForegroundKey);
            }
            if (this.selectedShadowKey != null) {
                color3 = UIManager.getColor(this.selectedShadowKey);
            }
            if (color3 == null) {
                color3 = MetalLookAndFeel.getPrimaryControlDarkShadow();
            }
            if (color2 == null) {
                color2 = MetalLookAndFeel.getWindowTitleForeground();
            }
            this.activeBumps.setBumpColors(this.activeBumpsHighlight, this.activeBumpsShadow, (UIManager.get("InternalFrame.activeTitleGradient") != null) ? null : color);
            metalBumps = this.activeBumps;
            s = "InternalFrame.activeTitleGradient";
        }
        else {
            if (!MetalLookAndFeel.usingOcean()) {
                this.closeButton.setContentAreaFilled(false);
                this.maxButton.setContentAreaFilled(false);
                this.iconButton.setContentAreaFilled(false);
            }
            color = MetalLookAndFeel.getWindowTitleInactiveBackground();
            color2 = MetalLookAndFeel.getWindowTitleInactiveForeground();
            color3 = MetalLookAndFeel.getControlDarkShadow();
            metalBumps = this.inactiveBumps;
            s = "InternalFrame.inactiveTitleGradient";
        }
        if (!MetalUtils.drawGradient(this, graphics, s, 0, 0, width, height, true)) {
            graphics.setColor(color);
            graphics.fillRect(0, 0, width, height);
        }
        graphics.setColor(color3);
        graphics.drawLine(0, height - 1, width, height - 1);
        graphics.drawLine(0, 0, 0, 0);
        graphics.drawLine(width - 1, 0, width - 1, 0);
        int x = leftToRight ? 5 : (width - 5);
        String title = this.frame.getTitle();
        Icon frameIcon = this.frame.getFrameIcon();
        if (frameIcon != null) {
            if (leftToRight == 0) {
                x -= frameIcon.getIconWidth();
            }
            frameIcon.paintIcon(this.frame, graphics, x, height / 2 - frameIcon.getIconHeight() / 2);
            x += (leftToRight ? (frameIcon.getIconWidth() + 5) : -5);
        }
        if (title != null) {
            Font font = this.getFont();
            graphics.setFont(font);
            FontMetrics fontMetrics = SwingUtilities2.getFontMetrics(this.frame, graphics, font);
            fontMetrics.getHeight();
            graphics.setColor(color2);
            int y = (height - fontMetrics.getHeight()) / 2 + fontMetrics.getAscent();
            Rectangle o = new Rectangle(0, 0, 0, 0);
            if (this.frame.isIconifiable()) {
                o = this.iconButton.getBounds();
            }
            else if (this.frame.isMaximizable()) {
                o = this.maxButton.getBounds();
            }
            else if (this.frame.isClosable()) {
                o = this.closeButton.getBounds();
            }
            String text;
            if (!(leftToRight == 0)) {
                if (o.x == 0) {
                    o.x = this.frame.getWidth() - this.frame.getInsets().right - 2;
                }
                text = this.getTitle(title, fontMetrics, o.x - x - 4);
            }
            else {
                text = this.getTitle(title, fontMetrics, x - o.x - o.width - 4);
                x -= SwingUtilities2.stringWidth(this.frame, fontMetrics, text);
            }
            int stringWidth = SwingUtilities2.stringWidth(this.frame, fontMetrics, text);
            SwingUtilities2.drawString(this.frame, graphics, text, x, y);
            x += (leftToRight ? (stringWidth + 5) : -5);
        }
        int n;
        if (!(leftToRight == 0)) {
            n = width - this.buttonsWidth - x - 5;
        }
        else {
            n = x - this.buttonsWidth - 5;
            x = this.buttonsWidth + 5;
        }
        int n2 = 3;
        metalBumps.setBumpArea(n, this.getHeight() - 2 * n2);
        metalBumps.paintIcon(this, graphics, x, n2);
        return;
    }
    
    public void setPalette(boolean isPalette) {
        this.isPalette = isPalette;
        if (this.isPalette) {
            this.closeButton.setIcon(this.paletteCloseIcon);
            if (this.frame.isMaximizable()) {
                this.remove(this.maxButton);
            }
            if (this.frame.isIconifiable()) {
                this.remove(this.iconButton);
            }
        }
        else {
            this.closeButton.setIcon(this.closeIcon);
            if (this.frame.isMaximizable()) {
                this.add(this.maxButton);
            }
            if (this.frame.isIconifiable()) {
                this.add(this.iconButton);
            }
        }
        this.revalidate();
        this.repaint();
    }
    
    private void updateOptionPaneState() {
        int intValue = -2;
        int wasClosable = this.wasClosable;
        Object clientProperty = this.frame.getClientProperty("JInternalFrame.messageType");
        if (clientProperty == null) {
            return;
        }
        if ((clientProperty instanceof Integer)) {
            intValue = (int)clientProperty;
        }
        switch (intValue) {
            case 0: {
                this.selectedBackgroundKey = "OptionPane.errorDialog.titlePane.background";
                this.selectedForegroundKey = "OptionPane.errorDialog.titlePane.foreground";
                this.selectedShadowKey = "OptionPane.errorDialog.titlePane.shadow";
                wasClosable = false;
                break;
            }
            case 3: {
                this.selectedBackgroundKey = "OptionPane.questionDialog.titlePane.background";
                this.selectedForegroundKey = "OptionPane.questionDialog.titlePane.foreground";
                this.selectedShadowKey = "OptionPane.questionDialog.titlePane.shadow";
                wasClosable = false;
                break;
            }
            case 2: {
                this.selectedBackgroundKey = "OptionPane.warningDialog.titlePane.background";
                this.selectedForegroundKey = "OptionPane.warningDialog.titlePane.foreground";
                this.selectedShadowKey = "OptionPane.warningDialog.titlePane.shadow";
                wasClosable = false;
                break;
            }
            case -1:
            case 1: {
                String selectedBackgroundKey = null;
                this.selectedShadowKey = selectedBackgroundKey;
                this.selectedForegroundKey = selectedBackgroundKey;
                this.selectedBackgroundKey = selectedBackgroundKey;
                wasClosable = false;
                break;
            }
            default: {
                String selectedBackgroundKey2 = null;
                this.selectedShadowKey = selectedBackgroundKey2;
                this.selectedForegroundKey = selectedBackgroundKey2;
                this.selectedBackgroundKey = selectedBackgroundKey2;
                break;
            }
        }
        if (wasClosable != (this.frame.isClosable() ? 1 : 0)) {
            this.frame.setClosable((boolean)wasClosable);
        }
        return;
    }
    
    static void access$300(MetalInternalFrameTitlePane metalInternalFrameTitlePane) {
        metalInternalFrameTitlePane.updateOptionPaneState();
    }
    
    static {
        handyEmptyBorder = new EmptyBorder(0, 0, 0, 0);
    }
    
    class MetalPropertyChangeHandler extends BasicInternalFrameTitlePane.PropertyChangeHandler
    {
        @Override
        public void propertyChange(PropertyChangeEvent evt) {
            String propertyName = evt.getPropertyName();
            if (propertyName.equals("selected")) {
                Boolean value = (Boolean)evt.getNewValue();
                MetalInternalFrameTitlePane.this.iconButton.putClientProperty("paintActive", value);
                MetalInternalFrameTitlePane.this.closeButton.putClientProperty("paintActive", value);
                MetalInternalFrameTitlePane.this.maxButton.putClientProperty("paintActive", value);
            }
            else if ("JInternalFrame.messageType".equals(propertyName)) {
                MetalInternalFrameTitlePane.access$300(MetalInternalFrameTitlePane.this);
                MetalInternalFrameTitlePane.this.frame.repaint();
            }
            super.propertyChange(evt);
        }
    }
    
    class MetalTitlePaneLayout extends BasicInternalFrameTitlePane.TitlePaneLayout
    {
        @Override
        public void addLayoutComponent(String s, Component component) {
        }
        
        @Override
        public void removeLayoutComponent(Component component) {
        }
        
        @Override
        public Dimension preferredLayoutSize(Container container) {
            return this.minimumLayoutSize(container);
        }
        
        @Override
        public Dimension minimumLayoutSize(Container container) {
            int n = 30;
            if (MetalInternalFrameTitlePane.this.frame.isClosable()) {
                n += 21;
            }
            if (MetalInternalFrameTitlePane.this.frame.isMaximizable()) {
                n += 16 + (MetalInternalFrameTitlePane.this.frame.isClosable() ? 10 : 4);
            }
            if (MetalInternalFrameTitlePane.this.frame.isIconifiable()) {
                n += 16 + (MetalInternalFrameTitlePane.this.frame.isMaximizable() ? 2 : (MetalInternalFrameTitlePane.this.frame.isClosable() ? 10 : 4));
            }
            FontMetrics fontMetrics = MetalInternalFrameTitlePane.this.frame.getFontMetrics(MetalInternalFrameTitlePane.this.getFont());
            String title = MetalInternalFrameTitlePane.this.frame.getTitle();
            int n2 = (title != null) ? SwingUtilities2.stringWidth(MetalInternalFrameTitlePane.this.frame, fontMetrics, title) : 0;
            int width;
            if (((title != null) ? title.length() : 0) > 2) {
                int stringWidth = SwingUtilities2.stringWidth(MetalInternalFrameTitlePane.this.frame, fontMetrics, MetalInternalFrameTitlePane.this.frame.getTitle().substring(0, 2) + "...");
                width = n + ((n2 < stringWidth) ? n2 : stringWidth);
            }
            else {
                width = n + n2;
            }
            int height2;
            if (MetalInternalFrameTitlePane.this.isPalette) {
                height2 = MetalInternalFrameTitlePane.this.paletteTitleHeight;
            }
            else {
                int height = fontMetrics.getHeight();
                height += 7;
                Icon frameIcon = MetalInternalFrameTitlePane.this.frame.getFrameIcon();
                int min = 0;
                if (frameIcon != null) {
                    min = Math.min(frameIcon.getIconHeight(), 16);
                }
                min += 5;
                height2 = Math.max(height, min);
            }
            return new Dimension(width, height2);
        }
        
        @Override
        public void layoutContainer(Container container) {
            int leftToRight = MetalUtils.isLeftToRight(MetalInternalFrameTitlePane.this.frame);
            int width = MetalInternalFrameTitlePane.this.getWidth();
            int n = leftToRight ? width : 0;
            int n2 = 2;
            int iconHeight = MetalInternalFrameTitlePane.this.closeButton.getIcon().getIconHeight();
            int iconWidth = MetalInternalFrameTitlePane.this.closeButton.getIcon().getIconWidth();
            if (MetalInternalFrameTitlePane.this.frame.isClosable()) {
                if (MetalInternalFrameTitlePane.this.isPalette) {
                    int n4 = 3;
                    n += (leftToRight ? (-n4 - (iconWidth + 2)) : n4);
                    MetalInternalFrameTitlePane.this.closeButton.setBounds(n, n2, iconWidth + 2, MetalInternalFrameTitlePane.this.getHeight() - 4);
                    if (leftToRight == 0) {
                        n += iconWidth + 2;
                    }
                }
                else {
                    int n3 = 4;
                    n += (leftToRight ? (-n3 - iconWidth) : n3);
                    MetalInternalFrameTitlePane.this.closeButton.setBounds(n, n2, iconWidth, iconHeight);
                    if (leftToRight == 0) {
                        n += iconWidth;
                    }
                }
            }
            if (MetalInternalFrameTitlePane.this.frame.isMaximizable() && !MetalInternalFrameTitlePane.this.isPalette) {
                int n5 = MetalInternalFrameTitlePane.this.frame.isClosable() ? 10 : 4;
                n += (leftToRight ? (-n5 - iconWidth) : n5);
                MetalInternalFrameTitlePane.this.maxButton.setBounds(n, n2, iconWidth, iconHeight);
                if (leftToRight == 0) {
                    n += iconWidth;
                }
            }
            if (MetalInternalFrameTitlePane.this.frame.isIconifiable() && !MetalInternalFrameTitlePane.this.isPalette) {
                int n6 = MetalInternalFrameTitlePane.this.frame.isMaximizable() ? 2 : (MetalInternalFrameTitlePane.this.frame.isClosable() ? 10 : 4);
                n += (leftToRight ? (-n6 - iconWidth) : n6);
                MetalInternalFrameTitlePane.this.iconButton.setBounds(n, n2, iconWidth, iconHeight);
                if (leftToRight == 0) {
                    n += iconWidth;
                }
            }
            MetalInternalFrameTitlePane.this.buttonsWidth = (leftToRight ? (width - n) : n);
        }
    }
}
